@@ -1,6 +1,6 @@
-/* netToe Version 1.1.0
- * Release date: 22 July 2001
- * Copyright 2000,2001 Gabriele Giorgetti <g.gabriele@europe.com>
+/* netToe Version 1.2.1
+ * Release date: 3 January 2010
+ * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,8 +19,9 @@
 */
 
 #define HOMEPAGE     "http://nettoe.sourceforge.net"
-#define AUTHOR_EMAIL "<g.gabriele@europe.com>"
-#define RELEASE_DATE "22 July 2001"
+#define AUTHOR_EMAIL "<ggdev@users.sourceforge.net>"
+#define AUTHOR2_EMAIL "<meand@users.sourceforge.net>"
+#define RELEASE_DATE "3 January 2010"
 
 #define SERVER_PORT_NUMBER 7501
 #define CLIENT_PORT_NUMBER 7502
