@@ -1,6 +1,7 @@
-/* netToe Version 1.1.0
- * Release date: 22 July 2001
- * Copyright 2000,2001 Gabriele Giorgetti <g.gabriele@europe.com>
+/* netToe Version 1.2.0
+ * Release date: 30 December 2009
+ * Copyright 2000,2001 Gabriele Giorgetti <ggdev@users.sourceforge.net>
+ *           2009 Mats Erik Andersson <meand@users.sourceforge.net>
  *		
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,8 +33,8 @@ int who_start_first (void)
 {
   int generated_number;
 
-  srand (time (0));
-  generated_number = 1 + (int) (10.0 * rand () / (RAND_MAX + 1.0));
+  srandom (time (0));
+  generated_number = 1 + (int) (10.0 * random () / (RAND_MAX + 1.0));
 
   if ((generated_number == 2) | (generated_number == 4) | (generated_number == 6) | (generated_number == 8) | (generated_number == 10))
     {
@@ -65,7 +66,7 @@ void beep ( void )
 
 void print_infos_screen (void)
 {
-  nettoe_term_set_color (COLOR_WHITE, COLOR_BLACK, ATTRIB_BRIGHT);
+  nettoe_term_reset_color();
   printf(" netToe is a Tic Tac Toe-like game for Linux and UNIX.    \n");
   printf(" It is possible to play it against the computer, another  \n");
   printf(" player on the same PC, or against another player over the\n");
@@ -79,20 +80,19 @@ void print_infos_screen (void)
   printf(" man nettoe 						    \n\n");
   nettoe_term_set_color (COLOR_BLUE, COLOR_BLACK, ATTRIB_BRIGHT);
   printf(" ------                                                   \n");
-  nettoe_term_set_color (COLOR_WHITE, COLOR_BLACK, ATTRIB_BRIGHT);
+  nettoe_term_reset_color();
   printf(" netToe %s                                                \n", VERSION);
   printf(" Copyright 2000,2001 Gabriele Giorgetti %s\n", AUTHOR_EMAIL);
+  printf("           2009      Mats Erik Andersson %s\n", AUTHOR2_EMAIL);
   printf(" %s                           \n", HOMEPAGE);
-  nettoe_term_set_color (COLOR_WHITE, COLOR_BLACK, ATTRIB_BRIGHT);
   printf("\nPress");
   nettoe_term_set_color (COLOR_RED, COLOR_BLACK, ATTRIB_BRIGHT);
   printf(" enter");
-  nettoe_term_set_color (COLOR_WHITE, COLOR_BLACK, ATTRIB_BRIGHT);
+  nettoe_term_reset_color();
   printf(" to go back to the main menu.\n");
    
   fflush (stdin);
 
-  getchar ();
   getchar ();
 
   nettoe_term_set_default_color();
@@ -122,7 +122,7 @@ void parse_cmd_args (int argc, char *argv[])
          fprintf(stdout, "The netToe project can be found at: %s\n", HOMEPAGE);
          fprintf(stdout, "\n");
          fprintf(stdout, "Please send any bug reports, or comments to:\n");
-         fprintf(stdout, "Gabriele Giorgetti %s\n", AUTHOR_EMAIL);
+         fprintf(stdout, "Mats Erik Andersson %s\n", AUTHOR2_EMAIL);
          
          exit(EXIT_SUCCESS);
      }
@@ -133,6 +133,7 @@ void parse_cmd_args (int argc, char *argv[])
          fprintf(stdout, "\n");
          fprintf(stdout, "Written by Gabriele Giorgetti %s\n", AUTHOR_EMAIL);
          fprintf(stdout, "Copyright 2000,2001 Gabriele Giorgetti\n");
+         fprintf(stdout, "          2009      Mats Erik Andersson\n");
          fprintf(stdout, "\n");
          fprintf(stdout, "This software is released under the GNU GPL.\n");
 
